==> dokuwiki-2014.09.29b.tgz: dokuwiki/lib/plugins/extension/lang/nl/lang.php <==
<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * 
 * @author Rene <wllywlnt@yahoo.com>
 * @author Gerrit Uitslag <klapinklapin@gmail.com>
 * @author Johan Vervloet <johan.vervloet@gmail.com>
 */
$lang['menu']                  = 'Uitbreidingen';
$lang['tab_plugins']           = 'Geïnstalleerde Plugins';
$lang['tab_templates']         = 'Geïnstalleerde Templates';
$lang['tab_search']            = 'Zoek en installeer';
$lang['tab_install']           = 'Handmatige installatie';
$lang['notimplemented']        = 'Deze toepassing is nog niet geïnstalleerd';
$lang['notinstalled']          = 'Deze uitbreiding is nog niet geïnstalleerd';
$lang['alreadyenabled']        = 'Deze uitbreiding is reeds ingeschakeld';
$lang['alreadydisabled']       = 'Deze uitbreiding is reeds uitgeschakeld';
$lang['pluginlistsaveerror']   = 'Fout bij het opslaan van de plugin lijst';
$lang['unknownauthor']         = 'Onbekende auteur';
$lang['unknownversion']        = 'Onbekende versie';
$lang['btn_info']              = 'Toon meer informatie';
$lang['btn_update']            = 'Update';
$lang['btn_uninstall']         = 'Deinstalleer';
$lang['btn_enable']            = 'Schakel aan';
$lang['btn_disable']           = 'Schakel uit';
$lang['btn_install']           = 'Installeer';
$lang['btn_reinstall']         = 'Her-installeer';
$lang['js']['reallydel']       = 'Wilt u deze uitbreiding deinstalleren?';
$lang['search_for']            = 'Zoek Uitbreiding:';
$lang['search']                = 'Zoek';
$lang['extensionby']           = '<strong>%s</strong> by %s';
$lang['screenshot']            = 'Schermafdruk bij %s';
$lang['popularity']            = 'Populariteit:%s%%';
$lang['homepage_link']         = 'Documentatie';
$lang['bugs_features']         = 'Bugs';
$lang['tags']                  = 'Tags:';
$lang['author_hint']           = 'Zoek uitbreidingen van deze auteur:';
$lang['installed']             = 'Geinstalleerd:';
$lang['downloadurl']           = 'Download URL:';
$lang['repository']            = 'Centrale opslag:';
$lang['unknown']               = '<em>onbekend</em>';
$lang['installed_version']     = 'Geïnstalleerde versie:';
$lang['install_date']          = 'Uw laatste update:';
$lang['available_version']     = 'Beschikbare versie:';
$lang['compatible']            = 'Compatible met:';
$lang['depends']               = 'Afhankelijk van:';
$lang['similar']               = 'Soortgelijk:';
$lang['conflicts']             = 'Conflicteerd met:';
$lang['donate']                = 'Vindt u dit leuk?';
$lang['donate_action']         = 'Koop een kop koffie voor de auteur!';
$lang['repo_retry']            = 'Herhaal';
$lang['provides']              = 'Zorgt voor:';
$lang['status']                = 'Status:';
$lang['status_installed']      = 'Geïnstalleerd';
$lang['status_not_installed']  = 'niet geïnstalleerd ';
$lang['status_protected']      = 'beschermd';
$lang['status_enabled']        = 'ingeschakeld';
$lang['status_disabled']       = 'uitgeschakeld';
$lang['status_unmodifiable']   = 'Niet wijzigbaar';
$lang['status_plugin']         = 'plugin';
$lang['status_template']       = 'template';
$lang['status_bundled']        = 'Gebundeld';
$lang['msg_enabled']           = 'Plugin %s ingeschakeld';
$lang['msg_disabled']          = 'Plugin %s uitgeschakeld';
$lang['msg_delete_success']    = 'Uitbreiding gedeinstalleerd';
$lang['msg_template_install_success'] = 'Template %s werd succesvol geïnstalleerd';
$lang['msg_template_update_success'] = 'Template %s werd succesvol geüpdatet';
$lang['msg_plugin_install_success'] = 'Plugin %s werd succesvol geïnstalleerd';
$lang['msg_plugin_update_success'] = 'Plugin %s werd succesvol geüpdatet';
$lang['msg_upload_failed']     = 'Uploaden van het bestand is mislukt';
$lang['missing_dependency']    = '<strong>niet aanwezige of uitgeschakelde afhankelijkheid</strong> %s';
$lang['security_issue']        = '<strong>Veiligheids kwestie:</strong> %s';
$lang['security_warning']      = '<strong>Veiligheids Waarschuwing</strong> %s';
$lang['update_available']      = '<strong>Update:</strong> Nieuwe versie %s is beschikbaar.';
$lang['wrong_folder']          = '<strong>Plugin onjuist geïnstalleerd:</strong> Hernoem de plugin directory van "%s" naar"%s"';
$lang['url_change']            = '<strong>URL gewijzigd:</strong> Download URL is gewijzigd sinds de laatste download. Controleer of de nieuwe URL juist is voordat u de uitbreiding updatet. <br />Nieuw:%s<Br /> Vorig: %s';
$lang['error_badurl']          = 'URLs moeten beginnen met http of https';
$lang['error_dircreate']       = 'De tijdelijke map kon niet worden gemaakt om de download te ontvangen';
$lang['error_download']        = 'Het is niet mogelijk het bestand te downloaden: %s';
$lang['error_decompress']      = 'Onmogelijk om het gedownloade bestand uit te pakken. Dit is wellicht het gevolg van een onvolledige/onjuiste download, in welk geval u het nog eens moet proberen; of het compressie formaat is onbekend in welk geval u het bestand handmatig moet downloaden en installeren.';
$lang['error_findfolder']      = 'Onmogelijk om de uitbreidings directory te vinden, u moet het zelf downloaden en installeren';
$lang['error_copy']            = 'Er was een bestand kopieer fout tijdens het installeren van bestanden in directory <em>%s</em>: de schijf kan vol zijn of de bestand toegangs rechten kunnen onjuist zijn. Dit kan tot gevolg hebben dat de plugin slechts gedeeltelijk werd geïnstalleerd waardoor uw wiki installatie onstabiel is ';
$lang['noperms']               = 'Uitbreidings directory is niet schrijfbaar';
$lang['notplperms']            = 'Template directory is niet schrijfbaar';
$lang['nopluginperms']         = 'Plugin directory is niet schrijfbaar';
$lang['git']                   = 'De uitbreiding werd geïnstalleerd via git, u wilt deze hier wellicht niet aanpassen.';
$lang['install_url']           = 'Installeer vanaf URL:';
$lang['install_upload']        = 'Upload Uitbreiding:';
$lang['repo_error']            = 'Er kon geen verbinding worden gemaakt met de centrale plugin opslag. Controleer of de server verbinding mag maken met www.dokuwiki.org en controleer de proxy instellingen.';

==> dokuwiki-2020.07.29p0.tgz: dokuwiki/lib/plugins/extension/lang/nl/lang.php <==
<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * @author Rene <wllywlnt@yahoo.com>
 * @author Gerrit Uitslag <klapinklapin@gmail.com>
 * @author Johan Vervloet <johan.vervloet@gmail.com>
 * @author Mijndert <mijndert@mijndertstuij.nl>
 * @author Johan Wijnker <johan@wijnker.eu>
 * @author Mark C. Prins <mprins@users.sf.net>
 * @author hugo smet <hugo.smet@scarlet.be>
 */
$lang['menu']                  = 'Uitbreidingen';
$lang['tab_plugins']           = 'Geïnstalleerde Plugins';
$lang['tab_templates']         = 'Geïnstalleerde Templates';
$lang['tab_search']            = 'Zoek en installeer';
$lang['tab_install']           = 'Handmatige installatie';
$lang['notimplemented']        = 'Deze toepassing is nog niet geïnstalleerd';
$lang['notinstalled']          = 'Deze uitbreiding is nog niet geïnstalleerd';
$lang['alreadyenabled']        = 'Deze uitbreiding is reeds ingeschakeld';
$lang['alreadydisabled']       = 'Deze uitbreiding is reeds uitgeschakeld';
$lang['pluginlistsaveerror']   = 'Fout bij het opslaan van de plugin lijst';
$lang['unknownauthor']         = 'Onbekende auteur';
$lang['unknownversion']        = 'Onbekende versie';
$lang['btn_info']              = 'Toon meer informatie';
$lang['btn_update']            = 'Update';
$lang['btn_uninstall']         = 'Deinstalleer';
$lang['btn_enable']            = 'Schakel aan';
$lang['btn_disable']           = 'Schakel uit';
$lang['btn_install']           = 'Installeer';
$lang['btn_reinstall']         = 'Her-installeer';
$lang['js']['reallydel']       = 'Wilt u deze uitbreiding deinstalleren?';
$lang['js']['display_viewoptions'] = 'Weergave opties:';
$lang['js']['display_enabled'] = 'ingeschakeld';
$lang['js']['display_disabled'] = 'uitgeschakeld';
$lang['js']['display_updatable'] = 'update beschikbaar';
$lang['search_for']            = 'Zoek Uitbreiding:';
$lang['search']                = 'Zoek';
$lang['extensionby']           = '<strong>%s</strong> by %s';
$lang['screenshot']            = 'Schermafdruk bij %s';
$lang['popularity']            = 'Populariteit: %s%%';
$lang['homepage_link']         = 'Documentatie';
$lang['bugs_features']         = 'Bugs';
$lang['tags']                  = 'Tags:';
$lang['author_hint']           = 'Zoek uitbreidingen van deze auteur:';
$lang['installed']             = 'Geinstalleerd:';
$lang['downloadurl']           = 'Download URL:';
$lang['repository']            = 'Centrale opslag:';
$lang['unknown']               = '<em>onbekend</em>';
$lang['installed_version']     = 'Geïnstalleerde versie:';
$lang['install_date']          = 'Uw laatste update:';
$lang['available_version']     = 'Beschikbare versie:';
$lang['compatible']            = 'Compatible met:';
$lang['depends']               = 'Afhankelijk van:';
$lang['similar']               = 'Soortgelijk:';
$lang['conflicts']             = 'Conflicteerd met:';
$lang['donate']                = 'Vindt u dit leuk?';
$lang['donate_action']         = 'Koop een kop koffie voor de auteur!';
$lang['repo_retry']            = 'Herhaal';
$lang['provides']              = 'Zorgt voor:';
$lang['status']                = 'Status:';
$lang['status_installed']      = 'Geïnstalleerd';
$lang['status_not_installed']  = 'niet geïnstalleerd ';
$lang['status_protected']      = 'beschermd';
$lang['status_enabled']        = 'ingeschakeld';
$lang['status_disabled']       = 'uitgeschakeld';
$lang['status_unmodifiable']   = 'Niet wijzigbaar';
$lang['status_plugin']         = 'plugin';
$lang['status_template']       = 'template';
$lang['status_bundled']        = 'Gebundeld';
$lang['msg_enabled']           = 'Plugin %s ingeschakeld';
$lang['msg_disabled']          = 'Plugin %s uitgeschakeld';
$lang['msg_delete_success']    = 'Uitbreiding %s gedeinstalleerd';
$lang['msg_delete_failed']     = 'Het deïnstalleren van de extensie %s is mislukt.';
$lang['msg_template_install_success'] = 'Template %s werd succesvol geïnstalleerd';
$lang['msg_template_update_success'] = 'Template %s werd succesvol geüpdatet';
$lang['msg_plugin_install_success'] = 'Plugin %s werd succesvol geïnstalleerd';
$lang['msg_plugin_update_success'] = 'Plugin %s werd succesvol geüpdatet';
$lang['msg_upload_failed']     = 'Uploaden van het bestand is mislukt';
$lang['missing_dependency']    = '<strong>niet aanwezige of uitgeschakelde afhankelijkheid</strong> %s';
$lang['security_issue']        = '<strong>Veiligheids kwestie:</strong> %s';
$lang['security_warning']      = '<strong>Veiligheids Waarschuwing</strong> %s';
$lang['update_available']      = '<strong>Update:</strong> Nieuwe versie %s is beschikbaar.';
$lang['wrong_folder']          = '<strong>Plugin onjuist geïnstalleerd:</strong> Hernoem de plugin directory van "%s" naar "%s"';
$lang['url_change']            = '<strong>URL gewijzigd:</strong> Download URL is gewijzigd sinds de laatste download. Controleer of de nieuwe URL juist is voordat u de uitbreiding updatet. <br />Nieuw:%s<Br /> Vorig: %s';
$lang['error_badurl']          = 'URLs moeten beginnen met http of https';
$lang['error_dircreate']       = 'De tijdelijke map kon niet worden gemaakt om de download te ontvangen';
$lang['error_download']        = 'Het is niet mogelijk het bestand te downloaden: %s';
$lang['error_decompress']      = 'Onmogelijk om het gedownloade bestand uit te pakken. Dit is wellicht het gevolg van een onvolledige/onjuiste download, in welk geval u het nog eens moet proberen; of het compressie formaat is onbekend in welk geval u het bestand handmatig moet downloaden en installeren.';
$lang['error_findfolder']      = 'Onmogelijk om de uitbreidings directory te vinden, u moet het zelf downloaden en installeren';
$lang['error_copy']            = 'Er was een bestand kopieer fout tijdens het installeren van bestanden in directory <em>%s</em>: de schijf kan vol zijn of de bestand toegangs rechten kunnen onjuist zijn. Dit kan tot gevolg hebben dat de plugin slechts gedeeltelijk werd geïnstalleerd waardoor uw wiki installatie onstabiel is ';
$lang['noperms']               = 'Uitbreidings directory is niet schrijfbaar';
$lang['notplperms']            = 'Template directory is niet schrijfbaar';
$lang['nopluginperms']         = 'Plugin directory is niet schrijfbaar';
$lang['git']                   = 'De uitbreiding werd geïnstalleerd via git, u wilt deze hier wellicht niet aanpassen.';
$lang['auth']                  = 'Deze auth plugin is niet geactiveerd in de configuratie, overweeg het om uit te schakelen.';
$lang['install_url']           = 'Installeer vanaf URL:';
$lang['install_upload']        = 'Upload Uitbreiding:';
$lang['repo_error']            = 'Er kon geen verbinding worden gemaakt met de centrale plugin opslag. Controleer of de server verbinding mag maken met www.dokuwiki.org en controleer de proxy instellingen.';
$lang['nossl']                 = 'Je PHP mist SSL ondersteuning. Downloaden werkt niet met veel DokuWiki extensies.';
